# REST client for the UW Catalyst Web Service

[![Build Status](https://github.com/uw-it-aca/uw-restclients-catalyst/workflows/tests/badge.svg?branch=main)](https://github.com/uw-it-aca/uw-restclients-catalyst/actions)
[![Coverage Status](https://coveralls.io/repos/uw-it-aca/uw-restclients-catalyst/badge.svg?branch=main)](https://coveralls.io/r/uw-it-aca/uw-restclients-catalyst?branch=main)
[![PyPi Version](https://img.shields.io/pypi/v/uw-restclients-catalyst.svg)](https://pypi.python.org/pypi/uw-restclients-catalyst)
![Python versions](https://img.shields.io/pypi/pyversions/uw-restclients-catalyst.svg)
